@@ -1,11 +1,25 @@
 # Paranoid::Log -- Log support for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# $Id: lib/Paranoid/Log.pm, 2.10 2022/03/08 00:01:04 acorliss Exp $
 #
-# $Id: lib/Paranoid/Log.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+# This software is free software.  Similar to Perl, you can redistribute it
+# and/or modify it under the terms of either:
 #
-#    This software is licensed under the same terms as Perl, itself.
-#    Please see http://dev.perl.org/licenses/ for more information.
+#   a)     the GNU General Public License
+#          <https://www.gnu.org/licenses/gpl-1.0.html> as published by the
+#          Free Software Foundation <http://www.fsf.org/>; either version 1
+#          <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+#          <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+#   b)     the Artistic License 2.0
+#          <https://opensource.org/licenses/Artistic-2.0>,
+#
+# subject to the following additional term:  No trademark rights to
+# "Paranoid" have been or are conveyed under any of the above licenses.
+# However, "Paranoid" may be used fairly to describe this unmodified
+# software, in good faith, but not as a trademark.
+#
+# (c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+# (tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 #
 #####################################################################
 
@@ -27,13 +41,13 @@ use Paranoid::Debug qw(:all);
 use Paranoid::Module;
 use Paranoid::Input;
 
-($VERSION) = ( q$Revision: 2.03 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.10 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT = qw(
     PL_DEBUG     PL_INFO      PL_NOTICE    PL_WARN
     PL_ERR       PL_CRIT      PL_ALERT     PL_EMERG
     PL_EQ        PL_NE        PL_GE        PL_LE
-    startLogger stopLogger plog
+    startLogger stopLogger plog plverbosity
     );
 @EXPORT_OK = (@EXPORT);
 %EXPORT_TAGS = ( all => [@EXPORT_OK], );
@@ -92,8 +106,7 @@ our @_levels = (
         my $mname  = $module;
         my ( $sref, $aref, $dref, $rv );
 
-        pdebug( 'entering w/(%s)', PDLEVEL2, $module );
-        pIn();
+        subPreamble( PDLEVEL2, '$', $module );
 
         # Was module already loaded (or a load attempted)?
         if ( exists $loaded{$module} ) {
@@ -110,7 +123,9 @@ our @_levels = (
 
                 # Yep, so try to load relative to Paranoid::Log
                 $rv =
-                    $mname eq 'Stderr' ? 1
+                      $mname eq 'Stderr' ? 1
+                    : $mname eq 'Stdout' ? 1
+                    : $mname eq 'PDebug' ? 1
                     : loadModule( "Paranoid::Log::$mname", '' )
                     && eval "Paranoid::Log::${mname}::init();"
                     && eval "\$sref = \\&Paranoid::Log::${mname}::logMsg;"
@@ -152,8 +167,7 @@ our @_levels = (
             }
         }
 
-        pOut();
-        pdebug( 'leaving w/rv: %s', PDLEVEL2, $rv );
+        subPostamble( PDLEVEL2, '$', $rv );
 
         return $rv;
     }
@@ -211,14 +225,18 @@ our @_levels = (
         my $mopts = shift;
         my $rv    = 1;
 
-        pdebug( 'entering w/(%s)(%s)(%s)(%s)(%s)',
-            PDLEVEL3, $name, $mech, $level, $scope, $mopts );
-        pIn();
+        subPreamble( PDLEVEL3, '$$$$\%', $name, $mech, $level, $scope,
+            $mopts );
 
         # Set defaults for optional arguments that were left undefined
         $level = PL_NOTICE unless defined $level;
         $scope = PL_GE     unless defined $scope;
 
+        # This is totally unnecessary, but we'll set PDebug to reflect
+        # how it actually operations in case anyone is looking at the
+        # distribution map
+        $level = PL_DEBUG if $mech eq 'PDebug';
+
         # Make sure this is a valid named logger
         unless ( defined $name and length $name ) {
             Paranoid::ERROR =
@@ -243,7 +261,7 @@ our @_levels = (
         # Make sure the module can be loaded if the log level was valid
         $rv = _loadModule($mech) if $rv;
 
-        # Make sure the log entry is uniqe
+        # Make sure the log entry is unique
         if ($rv) {
             if ( exists $loggers{$name} ) {
                 Paranoid::ERROR = pdebug( 'a logger for %s already exists',
@@ -259,9 +277,10 @@ our @_levels = (
                     scope     => $scope,
                     options   => {%$mopts} };
                 $rv =
-                    $mech eq 'Stderr'
-                    ? 1
-                    : &{ $msubs{$mech}[PL_AREF] }( %{ $loggers{$name} } );
+                      $mech eq 'Stderr' ? 1
+                    : $mech eq 'Stdout' ? 1
+                    : $mech eq 'PDebug' ? 1
+                    :   &{ $msubs{$mech}[PL_AREF] }( %{ $loggers{$name} } );
                 if ($rv) {
                     _updateDist();
                 } else {
@@ -270,8 +289,7 @@ our @_levels = (
             }
         }
 
-        pOut();
-        pdebug( 'leaving w/rv: %s', PDLEVEL3, $rv );
+        subPostamble( PDLEVEL3, '$', $rv );
 
         return $rv;
     }
@@ -287,7 +305,9 @@ our @_levels = (
 
         pdebug( 'deleting %s logger', PDLEVEL3, $name );
         if ( exists $loggers{$name} ) {
-            unless ( $loggers{$name}{mechanism} eq 'Stderr' ) {
+            unless ( $loggers{$name}{mechanism} eq 'Stderr'
+                or $loggers{$name}{mechanism} eq 'Stdout'
+                or $loggers{$name}{mechanism} eq 'PDebug' ) {
                 $rv =
                     &{ $msubs{ $loggers{$name}{mechanism} }[PL_DREF] }(
                     %{ $loggers{$name} } );
@@ -307,18 +327,19 @@ our @_levels = (
        # Returns:  True (1) if the message was succesfully logged,
        #           False (0) if there are any errors
        # Usage:    $rv = plog($severity, $message);
+       # Usage:    $rv = plog($severity, $message, @pdebugvals);
 
         my $level   = shift;
         my $message = shift;
+        my @margs   = @_;
         my $rv      = 1;
         my %record  = (
             severity => $level,
             message  => $message,
             );
-        my ( $logger, $sref );
+        my ( $logger, $sref, $plevel );
 
-        pdebug( 'entering w/(%s)(%s)', PDLEVEL1, $level, $message );
-        pIn();
+        subPreamble( PDLEVEL1, '$$;@', $level, $message, @margs );
 
         # Validate level and message
         $rv = 0
@@ -327,15 +348,53 @@ our @_levels = (
 
         if ($rv) {
 
+            # Trim leading/trailing whitespace and line terminators
+            $message =~ s/^[\s\r\n]+//s;
+            $message =~ s/[\s\r\n]+$//s;
+
+            # First, if PDebug was enabled, we'll preprocess messages through
+            # pdebug. *Every* message gets passed since pdebug has its own
+            # mechanism to decide what to display
+            if ( grep { $loggers{$_}{mechanism} eq 'PDebug' } keys %loggers )
+            {
+
+                # Paranoid::Debug uses an escalating scale of verbosity while
+                # this module uses an escalating scale of severity.  We can
+                # equate them in an inverse relationship, but we'll also need
+                # to increment the output value since pdebug equates 0 as
+                # disabled.
+                #
+                # Finally, we'll also make it a negative number to
+                # signal pdebug to dive deeper into the call stack to find the
+                # true originator of the message.  Otherwise, it would report
+                # plog as the originator, which is less than helpful.
+                $plevel = ( ( $level ^ 7 ) + 1 ) * -1;
+
+                # Send it to pdebug, but save the output
+                $message = pdebug( $message, $plevel, @margs );
+
+                # Substitute the processed output if we had any substitution
+                # values passed at all
+                $record{message} = $message if scalar @margs;
+
+            }
+
             # Iterate over the @dist level
             if ( defined $dist[$level] ) {
 
                 # Iterate over each logger
                 foreach $logger ( @{ $dist[$level] } ) {
+                    next if $loggers{$logger}{mechanism} eq 'PDebug';
+
                     if ( $loggers{$logger}{mechanism} eq 'Stderr' ) {
 
                         # Special handling for STDERR
-                        $rv = pderror($message) ? 1 : 0;
+                        $rv = pderror($message);
+
+                    } elsif ( $loggers{$logger}{mechanism} eq 'Stdout' ) {
+
+                        # Special handling for STDOUT
+                        $rv = print STDOUT "$message\n";
 
                     } else {
 
@@ -358,13 +417,62 @@ our @_levels = (
             $rv = 0;
         }
 
-        pOut();
-        pdebug( 'leaving w / rv : %s', PDLEVEL1, $rv );
+        subPostamble( PDLEVEL1, '$', $rv );
 
         return $rv;
     }
 }
 
+sub plverbosity {
+
+    # Purpose:  Sets Stdout/Stderr verbosity according to passed level.
+    #           Supports levels 1 - 3, with 4 being the most verbose
+    # Returns:  Boolean
+    # Usage:    $rv = plverbosity($level);
+
+    my $level  = shift;
+    my $max    = 3;
+    my $outidx = PL_NOTICE;
+    my $erridx = PL_CRIT;
+    my $rv     = 1;
+
+    subPreamble( PDLEVEL3, '$', $level );
+
+    # Make sure a positive integer was passed
+    $rv = 0 unless $level > -1;
+
+    # Cap $level
+    $level = $max if $level > $max;
+
+    # First, stop any current logging
+    foreach ( 0 .. 7 ) {
+        stopLogger( $_ < 3 ? "Stdout$_" : "Stderr$_" );
+    }
+
+    # Always enable PL_EMERG/PL_ALERT
+    if ($level) {
+        startLogger( "Stderr6", 'Stderr', PL_ALERT, PL_EQ );
+        startLogger( "Stderr7", 'Stderr', PL_EMERG, PL_EQ );
+    }
+
+    # Enable what's been asked
+    while ( $rv and $level ) {
+
+        # Start the levels
+        startLogger( "Stdout$outidx", 'Stdout', $outidx, PL_EQ );
+        startLogger( "Stderr$erridx", 'Stderr', $erridx, PL_EQ );
+
+        # Decrement the counters
+        $outidx--;
+        $erridx--;
+        $level--;
+    }
+
+    subPostamble( PDLEVEL3, '$', $rv );
+
+    return $rv;
+}
+
 1;
 
 __END__
@@ -375,7 +483,7 @@ Paranoid::Log - Log Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Log.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
+$Id: lib/Paranoid/Log.pm, 2.10 2022/03/08 00:01:04 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -386,6 +494,8 @@ $Id: lib/Paranoid/Log.pm, 2.03 2016/08/09 18:36:04 acorliss Exp $
 
   $rv = plog($severity, $message);
 
+  $rv = plverbosity(3);
+
 =head1 DESCRIPTION
 
 B<Paranoid::Log> provides a logging and message distribution framework that's
@@ -397,6 +507,20 @@ Additional modules exist on CPAN to allow for distribution to e-mail, syslog,
 and more.  It is also relatively trivial to write your own log mechanism to
 work with this framework.
 
+=head1 IMPORT LISTS
+
+This module exports the following symbols by default:
+
+    PL_DEBUG PL_INFO PL_NOTICE PL_WARN PL_ERR PL_CRIT
+    PL_ALERT PL_EMERG PL_EQ PL_NE PL_GE PL_LE
+    startLogger stopLogger plog plverbosity
+
+The following specialized import lists also exist:
+
+    List        Members
+    --------------------------------------------------------
+    all         @defaults
+
 =head1 LOGGING MECHANISMS
 
 Each logging mechanism is implemented as separate module consisting of
@@ -478,7 +602,7 @@ Scope is defined with the following characters:
                     or higher
   PL_LE           log only messages at this severity
                     or lower
-  PL_NE          log at all levels but this severity
+  PL_NE           log at all levels but this severity
 
 If omitted scope defaults to I<PL_GE>.
 
@@ -488,10 +612,12 @@ facilities provided directly by B<Paranoid> are as follows:
 
   mechanism        arguments
   =====================================================
-  Stderr          none
-  Buffer          bufferSize (optional)
-  File            file, mode (optional), perm (optional),
-                  syslog (optional)
+  Stdout           none
+  Stderr           none
+  Buffer           bufferSize (optional)
+  File             file, mode (optional), perm (optional),
+                   syslog (optional)
+  PDebug           none
 
 =head2 stopLogger
 
@@ -504,8 +630,43 @@ re-initializes the distribution processor.
 
   $rv = plog($severity, $message);
 
+  # If the PDebug mechanism is enabled
+  $rv = plog($severity, $message, @substitutions);
+
 This call logs the passed message to all facilities enabled at the specified
-log level.
+log level.  If you have B<PDebug> enabled as a mechanism this function can
+also provide an equivalent L<sprintf> functionality using the additional
+arguments, and that processed output will be shared with all other mechanisms
+that are enabled.
+
+B<NOTE:> I<PDebug> support is meant to be a convenience to unify both normal
+logging and the L<Paranoid::Debug::pdebug> B<STDERR> tracing mechanism.  That
+said, note than enabling it means that B<all> log messages are passed to
+L<pdebug>, since it has its own mechanism for deciding what gets sent to
+B<STDERR> or not.
+
+I<PDebug> support may not make sense for if your logging and debug output
+can't be neatly lined up with the syslog-styled severities.
+
+=head2 plverbosity
+
+    $rv = plverbosity($level);
+ 
+This function provides a simpler way to enable B<Stdout>/B<Stderr> logging to
+the appropriate level, if you consider B<PL_DEBUG> to B<PL_NOTICE> to be
+normal operation messages appropriate for B<STDOUT> messages, and B<PL_WARN>
+through B<PL_EMERG> to be error messages appropriate for B<STDERR>.
+
+This is primarily a convenience function for those simple, non-interactive
+programs/functions that need support varying levels of verbosity for the
+console.  From that perspective, it will be assumed that all user
+notifications would be simple one-line messages.
+
+B<NOTE:> I<PL_EMERG> and I<PL_ALERT> are always enabled if you use this
+function.  Any error messages that should always be printed to the console
+regardless of verbosity settings should be sent to one of those two levels.
+The remaining levels (I<PL_WARN> through I<PL_CRIT>) will be optionally
+enabled, just like I<PL_DEBUG>> through I<PL_NOTICE>.
 
 =head1 DEPENDENCIES
 
@@ -567,8 +728,22 @@ Arthur Corliss (corliss@digitalmages.com)
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is licensed under the same terms as Perl, itself. 
-Please see http://dev.perl.org/licenses/ for more information.
+This software is free software.  Similar to Perl, you can redistribute it
+and/or modify it under the terms of either:
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+  a)     the GNU General Public License
+         <https://www.gnu.org/licenses/gpl-1.0.html> as published by the 
+         Free Software Foundation <http://www.fsf.org/>; either version 1
+         <https://www.gnu.org/licenses/gpl-1.0.html>, or any later version
+         <https://www.gnu.org/licenses/license-list.html#GNUGPL>, or
+  b)     the Artistic License 2.0
+         <https://opensource.org/licenses/Artistic-2.0>,
+
+subject to the following additional term:  No trademark rights to
+"Paranoid" have been or are conveyed under any of the above licenses.
+However, "Paranoid" may be used fairly to describe this unmodified
+software, in good faith, but not as a trademark.
+
+(c) 2005 - 2020, Arthur Corliss (corliss@digitalmages.com)
+(tm) 2008 - 2020, Paranoid Inc. (www.paranoid.com)
 
